@@ -15,13 +15,13 @@ App::XML::DocBook::Docmake - translate DocBook/XML to other formats
 
 =head1 VERSION
 
-Version 0.0201
+Version 0.0300
 
 =cut
 
 use vars qw($VERSION);
 
-$VERSION = "0.0201";
+$VERSION = "0.0300";
 
 __PACKAGE__->mk_accessors(qw(
     _input_path
@@ -30,6 +30,7 @@ __PACKAGE__->mk_accessors(qw(
     _output_path
     _stylesheet
     _verbose
+    _real_mode
     _xslt_mode
     _xslt_stringparams
 ));
@@ -62,6 +63,10 @@ my %modes =
     'xhtml' =>
     {
     },
+    'xhtml-1_1' =>
+    {
+        real_mode => "xhtml",
+    },
     'rtf' =>
     {
         xslt_mode => "fo",
@@ -146,6 +151,16 @@ sub _init
     if ($mode_struct)
     {
         $self->_mode($mode);
+
+        if ($mode_struct->{real_mode})
+        {
+            $self->_real_mode($mode_struct->{real_mode});
+        }
+        else
+        {
+            $self->_real_mode($mode);
+        }
+
         if ($mode_struct->{xslt_mode})
         {
             $self->_xslt_mode($mode_struct->{xslt_mode});
@@ -195,9 +210,9 @@ sub run
 {
     my $self = shift;
 
-    my $mode = $self->_mode();
+    my $real_mode = $self->_real_mode();
 
-    my $mode_func = "_run_mode_$mode";
+    my $mode_func = '_run_mode_' . $self->_real_mode;
 
     return $self->$mode_func(@_);
 }
@@ -218,6 +233,7 @@ Available commands:
     rtf - convert to RTF (MS Word).
     pdf - convert to PDF (Adobe Acrobat).
     xhtml - convert to XHTML.
+    xhtml-1_1 - convert to XHTML-1.1.
 EOF
 }
 
@@ -287,6 +303,13 @@ sub _calc_default_xslt_stylesheet
         ;
 }
 
+sub _is_xhtml
+{
+    my $self = shift;
+
+    return (($self->_mode() eq "xhtml") || ($self->_mode() eq "xhtml-1_1"));
+}
+
 sub _calc_output_param_for_xslt
 {
     my $self = shift;
@@ -305,7 +328,7 @@ sub _calc_output_param_for_xslt
 
     # If it's XHTML, then it's a directory and xsltproc requires that
     # it will have a trailing slash.
-    if ($self->_mode() eq "xhtml")
+    if ($self->_is_xhtml)
     {
         if ($output_path !~ m{/\z})
         {
@@ -325,7 +348,7 @@ sub _calc_make_output_param_for_xslt
 
     # If it's XHTML, then we need to compare against the index.html
     # because the directory is freshly made.
-    if ($self->_mode() eq "xhtml")
+    if ($self->_is_xhtml)
     {
         $output_path .= "index.html";
     }
